.. include:: ../README.rst
   :end-before: About

.. include:: ../README.rst
   :start-after: -----
   :end-before: Features

.. toctree::
   :numbered:
   :maxdepth: 2

   introduction
   gettingstarted
   userguide
   administratorguide
   developerguide
   contributing
   changes
   license
   authors
